==> ae2omnicells-1.0.2-1.20.1.jar: assets/ae2omnicells/ae2guide/_zh_cn/cells.md <==
---
navigation:
  parent: index.md
  title: 存储元件
  icon: ae2omnicells:quantum_omni_cell_256m
  position: 20
item_ids:
  - omni_cell_housing
  - complex_omni_cell_housing
  - quantum_omni_cell_housing
  - omni_cell_component_1k
  - omni_cell_component_4k
  - omni_cell_component_16k
  - omni_cell_component_64k
  - omni_cell_component_256k
  - omni_cell_component_1m
  - omni_cell_component_4m
  - omni_cell_component_16m
  - omni_cell_component_64m
  - omni_cell_component_256m
  - complex_omni_cell_component_1k
  - complex_omni_cell_component_4k
  - complex_omni_cell_component_16k
  - complex_omni_cell_component_64k
  - complex_omni_cell_component_256k
  - complex_omni_cell_component_1m
  - complex_omni_cell_component_4m
  - complex_omni_cell_component_16m
  - complex_omni_cell_component_64m
  - complex_omni_cell_component_256m
  - quantum_omni_cell_component_1k
  - quantum_omni_cell_component_4k
  - quantum_omni_cell_component_16k
  - quantum_omni_cell_component_64k
  - quantum_omni_cell_component_256k
  - quantum_omni_cell_component_1m
  - quantum_omni_cell_component_4m
  - quantum_omni_cell_component_16m
  - quantum_omni_cell_component_64m
  - quantum_omni_cell_component_256m
  - omni_cell_1k
  - omni_cell_4k
  - omni_cell_16k
  - omni_cell_64k
  - omni_cell_256k
  - omni_cell_1m
  - omni_cell_4m
  - omni_cell_16m
  - omni_cell_64m
  - omni_cell_256m
  - complex_omni_cell_1k
  - complex_omni_cell_4k
  - complex_omni_cell_16k
  - complex_omni_cell_64k
  - complex_omni_cell_256k
  - complex_omni_cell_1m
  - complex_omni_cell_4m
  - complex_omni_cell_16m
  - complex_omni_cell_64m
  - complex_omni_cell_256m
  - quantum_omni_cell_1k
  - quantum_omni_cell_4k
  - quantum_omni_cell_16k
  - quantum_omni_cell_64k
  - quantum_omni_cell_256k
  - quantum_omni_cell_1m
  - quantum_omni_cell_4m
  - quantum_omni_cell_16m
  - quantum_omni_cell_64m
  - quantum_omni_cell_256m
  - portable_omni_cell_1k
  - portable_omni_cell_4k
  - portable_omni_cell_16k
  - portable_omni_cell_64k
  - portable_omni_cell_256k
  - portable_omni_cell_1m
  - portable_omni_cell_4m
  - portable_omni_cell_16m
  - portable_omni_cell_64m
  - portable_omni_cell_256m
  - portable_complex_omni_cell_1k
  - portable_complex_omni_cell_4k
  - portable_complex_omni_cell_16k
  - portable_complex_omni_cell_64k
  - portable_complex_omni_cell_256k
  - portable_complex_omni_cell_1m
  - portable_complex_omni_cell_4m
  - portable_complex_omni_cell_16m
  - portable_complex_omni_cell_64m
  - portable_complex_omni_cell_256m
  - portable_quantum_omni_cell_1k
  - portable_quantum_omni_cell_4k
  - portable_quantum_omni_cell_16k
  - portable_quantum_omni_cell_64k
  - portable_quantum_omni_cell_256k
  - portable_quantum_omni_cell_1m
  - portable_quantum_omni_cell_4m
  - portable_quantum_omni_cell_16m
  - portable_quantum_omni_cell_64m
  - portable_quantum_omni_cell_256m
---

# 存储元件

> 在**单个磁盘**中同时存放 AE 支持的任意资源类型：**物品、流体**，以及其他 AE 资源键。

本页涵盖三大系列（含便携版），容量统一为：**1k / 4k / 16k / 64k / 256k / 1m / 4m / 16m / 64m / 256m**。  
系列的区别仅在于 可同时存储的“种类数上限” 策略不同。

## 快速对比

| 系列 | 同时存储的种类上限 | 适用场景 |
|---|---:|---|
| **全能存储元件** | **63** 种 | 常规网络，类型较集中 |
| **复杂全能存储元件** | **随容量提升（12→6400）** | 类型随规模增长而激增的网络 |
| **量子存储元件** | **无限** | 超大规模、多样性极高的后期网络 |

---

## 全能存储元件
<Row>
  <ItemImage id="omni_cell_1k" scale="3" />
  <ItemImage id="omni_cell_4k" scale="3" />
  <ItemImage id="omni_cell_16k" scale="3" />
  <ItemImage id="omni_cell_64k" scale="3" />
  <ItemImage id="omni_cell_256k" scale="3" />
  <ItemImage id="omni_cell_1m" scale="3" />
  <ItemImage id="omni_cell_4m" scale="3" />
  <ItemImage id="omni_cell_16m" scale="3" />
  <ItemImage id="omni_cell_64m" scale="3" />
  <ItemImage id="omni_cell_256m" scale="3" />
</Row>

- **类型上限：63 种**
- 支持 AE 的所有资源类型（物品、流体等）混装于同一磁盘内。

---

## 复杂全能存储元件
<Row>
  <ItemImage id="complex_omni_cell_1k" scale="3" />
  <ItemImage id="complex_omni_cell_4k" scale="3" />
  <ItemImage id="complex_omni_cell_16k" scale="3" />
  <ItemImage id="complex_omni_cell_64k" scale="3" />
  <ItemImage id="complex_omni_cell_256k" scale="3" />
  <ItemImage id="complex_omni_cell_1m" scale="3" />
  <ItemImage id="complex_omni_cell_4m" scale="3" />
  <ItemImage id="complex_omni_cell_16m" scale="3" />
  <ItemImage id="complex_omni_cell_64m" scale="3" />
  <ItemImage id="complex_omni_cell_256m" scale="3" />
</Row>

- **类型上限会随容量提升而扩大**：  
  | 容量 | 1k | 4k | 16k | 64k | 256k | 1m | 4m | 16m | 64m | 256m |
  |---:|---:|---:|---:|---:|---:|---:|---:|---:|---:|---:|
  | 上限（种） | 12 | 25 | 50 | 100 | 200 | 400 | 800 | 1600 | 3200 | **6400** |

> 选择建议：当你预计**物品/流体种类**会随进度急剧上升时，此系列更具伸缩性与性价比。

---

## 量子存储元件
<Row>
  <ItemImage id="quantum_omni_cell_1k" scale="3" />
  <ItemImage id="quantum_omni_cell_4k" scale="3" />
  <ItemImage id="quantum_omni_cell_16k" scale="3" />
  <ItemImage id="quantum_omni_cell_64k" scale="3" />
  <ItemImage id="quantum_omni_cell_256k" scale="3" />
  <ItemImage id="quantum_omni_cell_1m" scale="3" />
  <ItemImage id="quantum_omni_cell_4m" scale="3" />
  <ItemImage id="quantum_omni_cell_16m" scale="3" />
  <ItemImage id="quantum_omni_cell_64m" scale="3" />
  <ItemImage id="quantum_omni_cell_256m" scale="3" />
</Row>

- **类型上限：无限**
- 适合需要同时存放**极其多样**资源类型的终极存储方案；
- 你几乎可以将所有类型的资源同时放入（仅受容量值大小限制）。

---

## 便携存储元件

以上每个系列与容量，均提供**对应的便携版本**。   
便携版与同系列磁盘行为一致，适合外出或离站访问网络使用场景。

---

## 数据保存

- **磁盘数据独立保存**：物品本体仅携带少量用于客户端 Tooltip 展示的信息，**无 NBT 过大风险**；
- **数据位置**：存档文件夹下data/ae_universal_cell_data。

==> ae2omnicells-1.0.5-1.21.1.jar: assets/ae2omnicells/ae2guide/_zh_cn/cells.md <==
---
navigation:
  parent: index.md
  title: 存储元件
  icon: ae2omnicells:quantum_omni_cell_256m
  position: 20
item_ids:
  - omni_cell_housing
  - complex_omni_cell_housing
  - quantum_omni_cell_housing
  - omni_cell_component_1k
  - omni_cell_component_4k
  - omni_cell_component_16k
  - omni_cell_component_64k
  - omni_cell_component_256k
  - omni_cell_component_1m
  - omni_cell_component_4m
  - omni_cell_component_16m
  - omni_cell_component_64m
  - omni_cell_component_256m
  - complex_omni_cell_component_1k
  - complex_omni_cell_component_4k
  - complex_omni_cell_component_16k
  - complex_omni_cell_component_64k
  - complex_omni_cell_component_256k
  - complex_omni_cell_component_1m
  - complex_omni_cell_component_4m
  - complex_omni_cell_component_16m
  - complex_omni_cell_component_64m
  - complex_omni_cell_component_256m
  - quantum_omni_cell_component_1k
  - quantum_omni_cell_component_4k
  - quantum_omni_cell_component_16k
  - quantum_omni_cell_component_64k
  - quantum_omni_cell_component_256k
  - quantum_omni_cell_component_1m
  - quantum_omni_cell_component_4m
  - quantum_omni_cell_component_16m
  - quantum_omni_cell_component_64m
  - quantum_omni_cell_component_256m
  - omni_cell_1k
  - omni_cell_4k
  - omni_cell_16k
  - omni_cell_64k
  - omni_cell_256k
  - omni_cell_1m
  - omni_cell_4m
  - omni_cell_16m
  - omni_cell_64m
  - omni_cell_256m
  - complex_omni_cell_1k
  - complex_omni_cell_4k
  - complex_omni_cell_16k
  - complex_omni_cell_64k
  - complex_omni_cell_256k
  - complex_omni_cell_1m
  - complex_omni_cell_4m
  - complex_omni_cell_16m
  - complex_omni_cell_64m
  - complex_omni_cell_256m
  - quantum_omni_cell_1k
  - quantum_omni_cell_4k
  - quantum_omni_cell_16k
  - quantum_omni_cell_64k
  - quantum_omni_cell_256k
  - quantum_omni_cell_1m
  - quantum_omni_cell_4m
  - quantum_omni_cell_16m
  - quantum_omni_cell_64m
  - quantum_omni_cell_256m
  - portable_omni_cell_1k
  - portable_omni_cell_4k
  - portable_omni_cell_16k
  - portable_omni_cell_64k
  - portable_omni_cell_256k
  - portable_omni_cell_1m
  - portable_omni_cell_4m
  - portable_omni_cell_16m
  - portable_omni_cell_64m
  - portable_omni_cell_256m
  - portable_complex_omni_cell_1k
  - portable_complex_omni_cell_4k
  - portable_complex_omni_cell_16k
  - portable_complex_omni_cell_64k
  - portable_complex_omni_cell_256k
  - portable_complex_omni_cell_1m
  - portable_complex_omni_cell_4m
  - portable_complex_omni_cell_16m
  - portable_complex_omni_cell_64m
  - portable_complex_omni_cell_256m
  - portable_quantum_omni_cell_1k
  - portable_quantum_omni_cell_4k
  - portable_quantum_omni_cell_16k
  - portable_quantum_omni_cell_64k
  - portable_quantum_omni_cell_256k
  - portable_quantum_omni_cell_1m
  - portable_quantum_omni_cell_4m
  - portable_quantum_omni_cell_16m
  - portable_quantum_omni_cell_64m
  - portable_quantum_omni_cell_256m
  - creative_ae_cell_long
  - creative_ae_cell_biginteger
---

# 存储元件

> 在**单个磁盘**中同时存放 AE 支持的任意资源类型：**物品、流体**，以及其他 AE 资源键。

本页涵盖三大系列（含便携版），容量统一为：**1k / 4k / 16k / 64k / 256k / 1m / 4m / 16m / 64m / 256m**。  
系列的区别仅在于 可同时存储的“种类数上限” 策略不同。

## 快速对比

| 系列 | 同时存储的种类上限 | 适用场景 |
|---|---:|---|
| **全能存储元件** | **63** 种 | 常规网络，类型较集中 |
| **复杂全能存储元件** | **随容量提升（12→6400）** | 类型随规模增长而激增的网络 |
| **量子存储元件** | **无限** | 超大规模、多样性极高的后期网络 |

---

## 全能存储元件
<Row>
  <ItemImage id="omni_cell_1k" scale="3" />
  <ItemImage id="omni_cell_4k" scale="3" />
  <ItemImage id="omni_cell_16k" scale="3" />
  <ItemImage id="omni_cell_64k" scale="3" />
  <ItemImage id="omni_cell_256k" scale="3" />
  <ItemImage id="omni_cell_1m" scale="3" />
  <ItemImage id="omni_cell_4m" scale="3" />
  <ItemImage id="omni_cell_16m" scale="3" />
  <ItemImage id="omni_cell_64m" scale="3" />
  <ItemImage id="omni_cell_256m" scale="3" />
</Row>

- **类型上限：63 种**
- 支持 AE 的所有资源类型（物品、流体等）混装于同一磁盘内。

---

## 复杂全能存储元件
<Row>
  <ItemImage id="complex_omni_cell_1k" scale="3" />
  <ItemImage id="complex_omni_cell_4k" scale="3" />
  <ItemImage id="complex_omni_cell_16k" scale="3" />
  <ItemImage id="complex_omni_cell_64k" scale="3" />
  <ItemImage id="complex_omni_cell_256k" scale="3" />
  <ItemImage id="complex_omni_cell_1m" scale="3" />
  <ItemImage id="complex_omni_cell_4m" scale="3" />
  <ItemImage id="complex_omni_cell_16m" scale="3" />
  <ItemImage id="complex_omni_cell_64m" scale="3" />
  <ItemImage id="complex_omni_cell_256m" scale="3" />
</Row>

- **类型上限会随容量提升而扩大**：  
  | 容量 | 1k | 4k | 16k | 64k | 256k | 1m | 4m | 16m | 64m | 256m |
  |---:|---:|---:|---:|---:|---:|---:|---:|---:|---:|---:|
  | 上限（种） | 12 | 25 | 50 | 100 | 200 | 400 | 800 | 1600 | 3200 | **6400** |

> 选择建议：当你预计**物品/流体种类**会随进度急剧上升时，此系列更具伸缩性与性价比。

---

## 量子存储元件
<Row>
  <ItemImage id="quantum_omni_cell_1k" scale="3" />
  <ItemImage id="quantum_omni_cell_4k" scale="3" />
  <ItemImage id="quantum_omni_cell_16k" scale="3" />
  <ItemImage id="quantum_omni_cell_64k" scale="3" />
  <ItemImage id="quantum_omni_cell_256k" scale="3" />
  <ItemImage id="quantum_omni_cell_1m" scale="3" />
  <ItemImage id="quantum_omni_cell_4m" scale="3" />
  <ItemImage id="quantum_omni_cell_16m" scale="3" />
  <ItemImage id="quantum_omni_cell_64m" scale="3" />
  <ItemImage id="quantum_omni_cell_256m" scale="3" />
</Row>

- **类型上限：无限**
- 适合需要同时存放**极其多样**资源类型的终极存储方案；
- 你几乎可以将所有类型的资源同时放入（仅受容量值大小限制）。

---

## 便携存储元件

以上每个系列与容量，均提供**对应的便携版本**。   
便携版与同系列磁盘行为一致，适合外出或离站访问网络使用场景。

---

## 创造存储元件
<Row>
  <ItemImage id="creative_ae_cell_long" scale="3" />
  <ItemImage id="creative_ae_cell_biginteger" scale="3" />
</Row>

- **LONG 级创造存储元件**：可用字节为 **long** 最大值。
- **BIG-INTEGER 级创造存储元件**：可用字节**无限**，但**性能较差**。可存储任意数量的资源；当存量超过 long 最大值时，**UI 不会显示超出部分**，但这些资源**实际存在且可用**。

创造存储元件**不提供默认配方**，如需使用请自行添加。

---

## 数据保存

- **磁盘数据独立保存**：物品本体仅携带少量用于客户端 Tooltip 展示的信息，**无 NBT 过大风险**；
- **数据位置**：存档文件夹下data/ae_universal_cell_data。
